==> crosspki-0.1.0.tar.gz: ios/Classes/SignatureAlgorithm.swift <==
//
//  SignatureAlgorithm.swift
//  Runner
//
//  Created by Lacuna Software on 5/13/20.
//

import Foundation

public class SignatureAlgorithm: BaseAlgorithm {
    
    public static let rsa = SignatureAlgorithm("RSA", "1.2.840.113549.1.1.1")
    
    fileprivate override init(_ name: String, _ oid: String) {
        super.init(name, oid)
    }
    
    public func getSecPadding(digestAlgorithm: DigestAlgorithm) throws -> SecPadding {
        if digestAlgorithm == DigestAlgorithm.md5 {
            return SecPadding.PKCS1MD5
            
        } else if (digestAlgorithm == DigestAlgorithm.sha1) {
            return SecPadding.PKCS1SHA1
            
        } else if (digestAlgorithm == DigestAlgorithm.sha224) {
            return SecPadding.PKCS1SHA224
            
        } else if (digestAlgorithm == DigestAlgorithm.sha256) {
            return SecPadding.PKCS1SHA256
           
        } else if (digestAlgorithm == DigestAlgorithm.sha384) {
            return SecPadding.PKCS1SHA384
          
        } else if (digestAlgorithm == DigestAlgorithm.sha512) {
            return SecPadding.PKCS1SHA512
           
        } else {
            throw CrossPkiError.error(.algorithmNotSupported, "Not supported digest algorithm for \(name) signature: \(digestAlgorithm)")
        }
    }
    
    @available(iOS 10.0, *)
    public func getMessageAlgorithm(digestAlgorithm: DigestAlgorithm) throws -> SecKeyAlgorithm {
        if digestAlgorithm == DigestAlgorithm.md5 {
            // not supported
            
        } else if digestAlgorithm == DigestAlgorithm.sha1 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA1
            
        } else if digestAlgorithm == DigestAlgorithm.sha224 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA224
            
        } else if digestAlgorithm == DigestAlgorithm.sha256 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA256
            
        } else if digestAlgorithm == DigestAlgorithm.sha384 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA384
            
        } else if digestAlgorithm == DigestAlgorithm.sha512 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA512
        }
        
        throw CrossPkiError.error(.algorithmNotSupported, "Not supported secKeyAlgorithm digest algorithm for \(name) signature: \(digestAlgorithm)")
    }
}

==> crosspki-1.1.0.tar.gz: ios/Classes/SignatureAlgorithm.swift <==
//
//  SignatureAlgorithm.swift
//  Runner
//
//  Created by Lacuna Software on 5/13/20.
//

import Foundation

public class SignatureAlgorithm: BaseAlgorithm {
    
    public static let rsa = SignatureAlgorithm("RSA", "1.2.840.113549.1.1.1", "-")
    
    fileprivate init(_ name: String, _ oid: String, _ avoidOverride: String) {
        super.init(name, oid)
    }
    
    public func getSecPadding(digestAlgorithm: DigestAlgorithm) throws -> SecPadding {
        if digestAlgorithm == DigestAlgorithm.md5 {
            return SecPadding.PKCS1MD5
            
        } else if (digestAlgorithm == DigestAlgorithm.sha1) {
            return SecPadding.PKCS1SHA1
            
        } else if (digestAlgorithm == DigestAlgorithm.sha224) {
            return SecPadding.PKCS1SHA224
            
        } else if (digestAlgorithm == DigestAlgorithm.sha256) {
            return SecPadding.PKCS1SHA256
           
        } else if (digestAlgorithm == DigestAlgorithm.sha384) {
            return SecPadding.PKCS1SHA384
          
        } else if (digestAlgorithm == DigestAlgorithm.sha512) {
            return SecPadding.PKCS1SHA512
           
        } else {
            throw CrossPkiError.error(.algorithmNotSupported, "Not supported digest algorithm for \(name) signature: \(digestAlgorithm)")
        }
    }
    
    @available(iOS 10.0, *)
    public func getMessageAlgorithm(digestAlgorithm: DigestAlgorithm) throws -> SecKeyAlgorithm {
        if digestAlgorithm == DigestAlgorithm.md5 {
            // not supported
            
        } else if digestAlgorithm == DigestAlgorithm.sha1 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA1
            
        } else if digestAlgorithm == DigestAlgorithm.sha224 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA224
            
        } else if digestAlgorithm == DigestAlgorithm.sha256 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA256
            
        } else if digestAlgorithm == DigestAlgorithm.sha384 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA384
            
        } else if digestAlgorithm == DigestAlgorithm.sha512 {
            return SecKeyAlgorithm.rsaSignatureMessagePKCS1v15SHA512
        }
        
        throw CrossPkiError.error(.algorithmNotSupported, "Not supported secKeyAlgorithm digest algorithm for \(name) signature: \(digestAlgorithm)")
    }
}
